<?php

declare(strict_types=1);

namespace Drupal\l10n_migrate\Plugin\migrate\source;

use Drupal\Core\Database\Query\SelectInterface;
use Drupal\Core\Site\Settings;
use Drupal\migrate\Plugin\migrate\source\SqlBase;

/**
 * Migrate Source plugin.
 *
 * @MigrateSource(
 *   id = "l10n_migrate_server_file",
 *   source_module = "l10n_migrate",
 * )
 */
class L10nServerFile extends SqlBase {

  /**
   * {@inheritdoc}
   */
  public function query(): SelectInterface {
    $query = $this
      ->select('l10n_server_file', 'f')
      ->fields(
        'f',
        [
          'fid',
          'pid',
          'rid',
          'location',
          'revision',
        ]
      );

    if ($pid = Settings::get('l10n_migrate_project_only')) {
      $query->condition('pid', $pid);
    }

    return $query;
  }

  /**
   * {@inheritdoc}
   */
  public function fields(): array {
    return [
      'fid' => $this->t('String ID'),
      'pid' => $this->t('Project ID'),
      'rid' => $this->t('Release ID'),
      'location' => $this->t('Location'),
      'revision' => $this->t('Revision'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIds(): array {
    return [
      'fid' => [
        'type' => 'integer',
        'alias' => 'f',
      ],
    ];
  }

}
