<?php

declare(strict_types=1);

namespace Drupal\l10n_migrate\Plugin\migrate\source;

use Drupal\Core\Database\Query\SelectInterface;
use Drupal\migrate\Plugin\migrate\source\SqlBase;
use Drupal\migrate\Row;

/**
 * Migrate Source plugin.
 *
 * @MigrateSource(
 *   id = "l10n_migrate_server_group_membership_node",
 *   source_module = "l10n_migrate",
 * )
 */
class L10nServerGroupMembershipNode extends SqlBase {

  /**
   * {@inheritdoc}
   */
  public function query(): SelectInterface {
    $query = $this->select('og_membership', 'ogm');
    $query->join('node', 'n', 'n.nid = ogm.gid');
    $query->join('node', 'content', 'content.nid = ogm.etid');
    $query->addField('ogm', 'id');
    $query->addField('ogm', 'etid');
    $query->addField('ogm', 'gid');
    $query->addField('n', 'uid');
    $query->addField('content', 'type');
    $query->addField('content', 'title');
    $query->addField('ogm', 'created');
    $query->condition('ogm.entity_type', 'node');
    $query->orderBy('ogm.id');

    return $query;
  }

  /**
   * {@inheritdoc}
   */
  public function prepareRow(Row $row): bool {
    // 'translation-group_node-story'
    $row->setSourceProperty('relationship_type', 'translation-group_' . $row->getSourceProperty('type'));

    return parent::prepareRow($row);
  }

  /**
   * {@inheritdoc}
   */
  public function fields(): array {
    return [
      'id' => $this->t('Integer containing the group membership ID.'),
      'etid' => $this->t('Integer containing the {users}.uid'),
      'gid' => $this->t('Integer containing the {og_membership}.gid'),
      'created' => $this->t('The Unix timestamp when the group content was created.'),
      'uid' => $this->t('Integer containing the {users}.uid who created the group content.'),
      'type' => $this->t('String containing the {node}.type.'),
      'title' => $this->t('String containing the {node}.title.'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIds(): array {
    return [
      'id' => [
        'type' => 'integer',
        'alias' => 'ogm',
      ],
    ];
  }

}
