<?php

declare(strict_types=1);

namespace Drupal\l10n_migrate\Plugin\migrate\source;

use Drupal\Core\Database\Query\SelectInterface;
use Drupal\migrate\Plugin\migrate\source\SqlBase;
use Drupal\migrate\Row;

/**
 * Migrate Source plugin.
 *
 * @MigrateSource(
 *   id = "l10n_migrate_server_group_membership_user",
 *   source_module = "l10n_migrate",
 * )
 */
class L10nServerGroupMembershipUser extends SqlBase {

  /**
   * {@inheritdoc}
   */
  public function query(): SelectInterface {
    $query = $this->select('og_membership', 'ogm');
    $query->join('users', 'u', 'u.uid = ogm.etid');
    $query->join('node', 'n', 'n.nid = ogm.gid AND n.uid <> ogm.etid');
    $query->addField('ogm', 'id');
    $query->addField('ogm', 'etid');
    $query->addField('ogm', 'gid');
    $query->addField('n', 'uid');
    $query->addField('ogm', 'created');
    $query->addField('u', 'name');
    $query->condition('ogm.entity_type', 'user');
    $query->condition('n.type', 'l10n_group');
    $query->orderBy('ogm.id');

    return $query;
  }

  /**
   * {@inheritdoc}
   */
  public function prepareRow(Row $row): bool {
    $uid = $row->getSourceProperty('etid');
    $gid = $row->getSourceProperty('gid');

    $rids = $this->select('og_users_roles', 'ogur')
      ->fields('ogur', ['rid'])
      ->condition('ogur.uid', $uid)
      ->condition('ogur.gid', $gid)
      ->orderBy('ogur.rid')
      ->execute()
      ->fetchCol();

    $row->setSourceProperty('rids', $rids);

    return parent::prepareRow($row);
  }

  /**
   * {@inheritdoc}
   */
  public function fields(): array {
    return [
      'id' => $this->t('Integer containing the group membership ID.'),
      'uid' => $this->t('Integer containing the {users}.uid who created the group content.'),
      'etid' => $this->t('Integer containing the {users}.uid'),
      'gid' => $this->t('Integer containing the {og_membership}.gid'),
      'created' => $this->t('The Unix timestamp when the group content was created.'),
      'name' => $this->t('String containing the {users}.name.'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIds(): array {
    return [
      'id' => [
        'type' => 'integer',
        'alias' => 'ogm',
      ],
    ];
  }

}
