<?php

namespace Drupal\l10n_packager\Drush\Commands;

use Drupal\l10n_packager\L10nPackager;
use Drush\Attributes as CLI;
use Drush\Commands\DrushCommands;
use Drush\Drush;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A Drush commandfile.
 */
final class L10nPackagerCommands extends DrushCommands {

  /**
   * Constructs a L10nPackagerCommands object.
   */
  public function __construct(
    private readonly L10nPackager $packager,
  ) {
    parent::__construct();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('l10n_packager.packager'),
    );
  }

  /**
   * Package releases.
   *
   * Used by the cron for all releases (default).
   * Optionally, use a specific project with the Drush command.
   */
  #[CLI\Command(name: 'l10n_packager:package', aliases: ['lpp'])]
  #[CLI\Argument(name: 'project', description: 'Optional project to scan for updates.')]
  #[CLI\Usage(name: 'l10n_packager:package foo', description: 'Usage with optional project.')]
  public function package(string $project = ''): void {
    [$checked, $updated, $time] = $this->packager->checkUpdates($project);
    Drush::output()->writeln(dt('@ms ms for @checked releases/@updated files.', [
      '@checked' => $checked,
      '@updated' => $updated,
      '@ms' => $time,
    ]));
  }

}
