<?php

declare(strict_types=1);

namespace Drupal\l10n_server\Entity;

use Drupal\Core\Entity\ContentEntityInterface;

/**
 * Provides an interface defining a history entity type.
 */
interface L10nServerTranslationHistoryInterface extends ContentEntityInterface {

  /**
   * Gets action UID.
   *
   * @return int|null
   *   The action UID integer, or NULL.
   */
  public function getActionUid(): ?int;

  /**
   * Sets action UID.
   *
   * @param int $uid
   *   The action UID integer.
   *
   * @return $this
   *   The entity object.
   */
  public function setActionUid(int $uid): self;

  /**
   * Gets action time.
   *
   * @return int
   *   The action time integer.
   */
  public function getActionTime(): int;

  /**
   * Sets action time.
   *
   * @param int $time
   *   The action time integer.
   *
   * @return $this
   *   The entity object.
   */
  public function setActionTime(int $time): self;

  /**
   * Gets action type.
   *
   * @return string
   *   The action type string.
   */
  public function getActionType(): int;

  /**
   * Sets action type.
   *
   * @param int $type
   *   The action type integer.
   *
   * @return $this
   *   The entity object.
   */
  public function setActionType(int $type): self;

  /**
   * Gets action medium.
   *
   * @return string
   *   The action medium string.
   */
  public function getActionMedium(): int;

  /**
   * Sets action medium.
   *
   * @param int $medium
   *   The action medium integer.
   *
   * @return $this
   *   The entity object.
   */
  public function setActionMedium(int $medium): self;

}
